@@ -4,6 +4,7 @@ import urllib3
 import json
 import re
 import os
+import urllib3
 
 import pandas as pd
 import ratelimit
@@ -62,8 +63,8 @@ class OpenFigiClient:
             self._search_filter_result_limit = 150
 
 
-        retries = urllib3.util.retry.Retry(total=2, 
-                backoff_factor=1,
+        retries = urllib3.util.retry.Retry(total=5, 
+                backoff_factor=2,
                 status_forcelist=[429, 500, 503, 502, 413, 504])
 
         ada = requests.adapters.HTTPAdapter(max_retries=retries)
@@ -85,7 +86,7 @@ class OpenFigiClient:
             yield l[i:i + n]# }}}
 
     @ratelimit.sleep_and_retry# {{{
-    @ratelimit.limits(calls=25, period=6)
+    @ratelimit.limits(calls=25, period=9)
     def _send_auth_mapping_request(self, js):
         """send the complete request to the Open FIGI API, with API key rate limit
 
@@ -144,7 +145,7 @@ class OpenFigiClient:
 
         df = pd.DataFrame({'idType': ['ID_BB_GLOBAL'] * len(figis), 'idValue': figis})
 
-        return self.map_dataframe(df)
+        return self.map(df)
         # }}}
 
     @ratelimit.sleep_and_retry# {{{
@@ -195,7 +196,7 @@ class OpenFigiClient:
             json_result = self._send_auth_search_filter_request(js, typ=typ)
         else:
             json_result = self._send_unauth_search_filter_request(js, typ=typ)
-        print(js)
+        # print(js)
         return json_result# }}}
 
     @cached(cache=TTLCache(maxsize=10, ttl=43200))# {{{
